@@ -81,7 +81,7 @@ class MYSQLExporter(Result):
     def save(self, query, args, status=True):
         try:
             if self.args.get_only_ff:
-                args=[args[0], args[1]]
+                args=[2, args[0]]
                 print args
             print(query %tuple(args))
             self.sqlconn.cursor().execute(query %tuple(args))
